summaryrefslogtreecommitdiffstats
path: root/src/render/backend/uniform_p.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/render/backend/uniform_p.h')
-rw-r--r--src/render/backend/uniform_p.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/render/backend/uniform_p.h b/src/render/backend/uniform_p.h
index 09575a077..eb959923a 100644
--- a/src/render/backend/uniform_p.h
+++ b/src/render/backend/uniform_p.h
@@ -56,7 +56,7 @@
#include <Qt3DCore/private/matrix4x4_p.h>
#include <Qt3DCore/private/vector3d_p.h>
#include <Qt3DCore/private/vector4d_p.h>
-
+#include <Qt3DRender/private/qt3drender_global_p.h>
#include <QMatrix4x4>
#include <QVector2D>
#include <QVector3D>
@@ -105,7 +105,7 @@ enum UniformType {
Unknown
};
-class Q_AUTOTEST_EXPORT UniformValue
+class Q_3DRENDERSHARED_PRIVATE_EXPORT UniformValue
{
public:
enum ValueType {
@@ -227,9 +227,9 @@ public:
return !(*this == other);
}
private:
// Allocate 4 floats on stack
// For larger elements, heap allocation will be used
- QVarLengthArray<float, 4> m_data;
+ QVarLengthArray<float, 16> m_data;
ValueType m_valueType = ScalarValue;
@@ -238,7 +238,7 @@ private:
};
template<>
-Q_AUTOTEST_EXPORT void UniformValue::setData<QMatrix4x4>(const QVector<QMatrix4x4> &v);
+Q_3DRENDERSHARED_PRIVATE_EXPORT void UniformValue::setData<QMatrix4x4>(const QVector<QMatrix4x4> &v);
} // namespace Render
} // namespace Qt3DRender
@@ -227,9 +227,9 @@ public:
}
private:
- // Allocate 4 floats on stack
+ // Allocate 16 floats on stack
// For larger elements, heap allocation will be used